@@ -1,4 +1,4 @@
-/* $Id: Local.c,v 1.10 2004/04/06 15:09:16 dk Exp $ */
+/* $Id: Local.c,v 1.12 2007/08/21 12:10:29 dk Exp $ */
 
 #include <stdarg.h>
 #include "IPAsupp.h"
@@ -6,8 +6,6 @@
 #include "Local.inc"
 #include "LocalSupp.h"
 
-static SV **temporary_prf_Sv;
-
 /*    Sobel */
 #define SOBEL_COLUMN            0x0001
 #define SOBEL_ROW               0x0002
@@ -21,24 +19,6 @@ typedef enum {
     sobelNESW=3
 } OPERATOR_TYPE;
 
-PImage_vmt CImage;
-
-XS( boot_IPA__Local)
-{
-    dXSARGS;
-
-    (void)items;
-
-    XS_VERSION_BOOTCHECK;
-
-    register_IPA__Local_Package();
-
-    CImage = (PImage_vmt)gimme_the_vmt( "Prima::Image");
-
-    ST(0) = &sv_yes;
-    XSRETURN(1);
-}
-
 /*******************************************************************
  * Function    : crispeningByte
  * Parameters  : PImage img
@@ -441,6 +421,7 @@ PImage fast_sobel( PImage srcimg,
 
 PImage IPA__Local_sobel(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::sobel";
     PImage oimg;
     unsigned short jobMask=SOBEL_NWSE|SOBEL_NESW;
@@ -706,6 +687,7 @@ filter3x3( const char * method, PImage img,
 
 PImage IPA__Local_filter3x3(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::filter3x3";
     unsigned short conversionType=CONV_SCALEABS;
     unsigned short edgecolor=0;
@@ -965,6 +947,7 @@ PImage fast_median(PImage srcimg, int wx, int wy)
 
 PImage IPA__Local_median(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::median";
     PImage oimg;
     int wx=0,wy=0;
@@ -1146,6 +1129,7 @@ PImage union_find_ave( PImage in, int threshold)
 
 PImage IPA__Local_unionFind(PImage img,HV *profile)
 {
+    dPROFILE;
     typedef enum {
         UAve, Unknown=-1
     } UMethod;
@@ -1206,6 +1190,7 @@ PImage IPA__Local_unionFind(PImage img,HV *profile)
 
 PImage IPA__Local_deriche(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::deriche";
     float alpha;
 
@@ -1278,6 +1263,7 @@ hysteresis( PImage img, int thr0, int thr1, int conn8)
 
 PImage IPA__Local_hysteresis(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::hysteresis";
     int thr1, thr0, neighborhood = 8;
 
@@ -1723,6 +1709,7 @@ canny( const char * method,
 
 PImage IPA__Local_canny(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::canny";
     int size = 3;
     double sigma = 2;
@@ -1744,25 +1731,28 @@ PImage IPA__Local_canny(PImage img,HV *profile)
 /* non-maxima suppression */
 PImage IPA__Local_nms(PImage img,HV *profile)
 {
-    double color = 0;
+    dPROFILE;
+    double set   = 0xFF;
+    double clear = 0;
     const char *method="IPA::Local::nms";
     PImage out;
 
     if ( !img || !kind_of(( Handle) img, CImage))
       croak("%s: not an image passed", method);
 
-    if ( pexist(color)) color = pget_f(color);
+    if ( pexist(set))   set   = pget_f(set);
+    if ( pexist(clear)) clear = pget_f(clear);
     out = create_compatible_image( img, true);
     PIX_SRC_DST( img, out, 
               *dst = (
                 (y > 0 && (
-                   (x > 0 && src[src_ls-1] > *src) || (x < w - 1 && src[src_ls+1] > *src) 
+                   (x > 0 && src[-src_ls-1] > *src) || (x < w - 1 && src[-src_ls+1] > *src) || (src[-src_ls] > *src)
                 )) || 
                 (y < h-1 && (
-                   (x > 0 && src[src_ls-1] > *src) || (x < w - 1 && src[src_ls+1] > *src) 
+                   (x > 0 && src[src_ls-1] > *src) || (x < w - 1 && src[src_ls+1] > *src) || (src[src_ls] > *src)
                 )) || 
                 (x > 0 && src[-1] > *src) || (x < w - 1 && src[1] > *src)
-              ) ? color : *src
+              ) ? clear : set
     ); 
     return out;
 }
@@ -1789,6 +1779,7 @@ scale( const char * method,
 
 PImage IPA__Local_scale(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::scale";
     int size = 3;
     double t = 4;
@@ -1861,6 +1852,7 @@ d_rotate90( PImage in)
  */
 PImage IPA__Local_ridge(PImage img,HV *profile)
 {
+    dPROFILE;
     PImage xx, yy, xy, yx, lxx, lyy, lxy, lyx, l, tmp;
     Bool anorm = false;
     const char *method="IPA::Local::ridge";
@@ -1953,6 +1945,7 @@ PImage IPA__Local_ridge(PImage img,HV *profile)
 PImage 
 IPA__Local_zerocross(PImage img,HV *profile)
 {
+    dPROFILE;
     const char *method="IPA::Local::zerocross";
     double cmp = 0;
     int p, n;
